==> devops-client-java-1.0.2-sources.jar: io/alauda/devops/java/client/models/V1alpha1PipelineSourceBuilder.java <==
package io.alauda.devops.java.client.models;

import io.alauda.devops.java.client.fluent.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class V1alpha1PipelineSourceBuilder extends V1alpha1PipelineSourceFluentImpl<V1alpha1PipelineSourceBuilder> implements VisitableBuilder<V1alpha1PipelineSource,V1alpha1PipelineSourceBuilder>{

    V1alpha1PipelineSourceFluent<?> fluent;
    Boolean validationEnabled;

    public V1alpha1PipelineSourceBuilder(){
            this(true);
    }
    public V1alpha1PipelineSourceBuilder(Boolean validationEnabled){
            this(new V1alpha1PipelineSource(), validationEnabled);
    }
    public V1alpha1PipelineSourceBuilder(V1alpha1PipelineSourceFluent<?> fluent){
            this(fluent, true);
    }
    public V1alpha1PipelineSourceBuilder(V1alpha1PipelineSourceFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new V1alpha1PipelineSource(), validationEnabled);
    }
    public V1alpha1PipelineSourceBuilder(V1alpha1PipelineSourceFluent<?> fluent,V1alpha1PipelineSource instance){
            this(fluent, instance, true);
    }
    public V1alpha1PipelineSourceBuilder(V1alpha1PipelineSourceFluent<?> fluent,V1alpha1PipelineSource instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withCodeRepository(instance.getCodeRepository());

            fluent.withGit(instance.getGit());

            fluent.withSecret(instance.getSecret());

            fluent.withSourceType(instance.getSourceType());

            fluent.withSvn(instance.getSvn());

            this.validationEnabled = validationEnabled; 
    }
    public V1alpha1PipelineSourceBuilder(V1alpha1PipelineSource instance){
            this(instance,true);
    }
    public V1alpha1PipelineSourceBuilder(V1alpha1PipelineSource instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withCodeRepository(instance.getCodeRepository());

            this.withGit(instance.getGit());

            this.withSecret(instance.getSecret());

            this.withSourceType(instance.getSourceType());

            this.withSvn(instance.getSvn());

            this.validationEnabled = validationEnabled; 
    }

    public V1alpha1PipelineSource build(){
            V1alpha1PipelineSource buildable = new V1alpha1PipelineSource();
            buildable.setCodeRepository(fluent.getCodeRepository());
            buildable.setGit(fluent.getGit());
            buildable.setSecret(fluent.getSecret());
            buildable.setSourceType(fluent.getSourceType());
            buildable.setSvn(fluent.getSvn());
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1alpha1PipelineSourceBuilder that = (V1alpha1PipelineSourceBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> devops-client-java-1.0.6-sources.jar: io/alauda/devops/java/client/models/V1alpha1PipelineSourceBuilder.java <==
package io.alauda.devops.java.client.models;

import io.alauda.devops.java.client.fluent.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class V1alpha1PipelineSourceBuilder extends V1alpha1PipelineSourceFluentImpl<V1alpha1PipelineSourceBuilder> implements VisitableBuilder<V1alpha1PipelineSource,V1alpha1PipelineSourceBuilder>{

    V1alpha1PipelineSourceFluent<?> fluent;
    Boolean validationEnabled;

    public V1alpha1PipelineSourceBuilder(){
            this(true);
    }
    public V1alpha1PipelineSourceBuilder(Boolean validationEnabled){
            this(new V1alpha1PipelineSource(), validationEnabled);
    }
    public V1alpha1PipelineSourceBuilder(V1alpha1PipelineSourceFluent<?> fluent){
            this(fluent, true);
    }
    public V1alpha1PipelineSourceBuilder(V1alpha1PipelineSourceFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new V1alpha1PipelineSource(), validationEnabled);
    }
    public V1alpha1PipelineSourceBuilder(V1alpha1PipelineSourceFluent<?> fluent,V1alpha1PipelineSource instance){
            this(fluent, instance, true);
    }
    public V1alpha1PipelineSourceBuilder(V1alpha1PipelineSourceFluent<?> fluent,V1alpha1PipelineSource instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withCodeRepository(instance.getCodeRepository());

            fluent.withDisk(instance.getDisk());

            fluent.withGit(instance.getGit());

            fluent.withSecret(instance.getSecret());

            fluent.withSourceType(instance.getSourceType());

            fluent.withSvn(instance.getSvn());

            this.validationEnabled = validationEnabled; 
    }
    public V1alpha1PipelineSourceBuilder(V1alpha1PipelineSource instance){
            this(instance,true);
    }
    public V1alpha1PipelineSourceBuilder(V1alpha1PipelineSource instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withCodeRepository(instance.getCodeRepository());

            this.withDisk(instance.getDisk());

            this.withGit(instance.getGit());

            this.withSecret(instance.getSecret());

            this.withSourceType(instance.getSourceType());

            this.withSvn(instance.getSvn());

            this.validationEnabled = validationEnabled; 
    }

    public V1alpha1PipelineSource build(){
            V1alpha1PipelineSource buildable = new V1alpha1PipelineSource();
            buildable.setCodeRepository(fluent.getCodeRepository());
            buildable.setDisk(fluent.getDisk());
            buildable.setGit(fluent.getGit());
            buildable.setSecret(fluent.getSecret());
            buildable.setSourceType(fluent.getSourceType());
            buildable.setSvn(fluent.getSvn());
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1alpha1PipelineSourceBuilder that = (V1alpha1PipelineSourceBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
